# User Documents Link

### 1. Geochemistry π Project Introduction

+ [Project Introduction](https://geochemistrypi.readthedocs.io/en/latest/Introduction/Introduction.html)

### 2. Code Download Link
+ [Github link](https://github.com/ZJUEarthData/geochemistrypi)
+ [Gitee link](https://gitee.com/zju-earth-data/geochemistrypy)

### 3. Installing and Model Running Video
+ [Geochemistry π - The Currently Fastest Feasible Installation Method in China — Installing from GitHub Using Requirements - Keran Li (Kirk)](https://www.bilibili.com/video/BV1pM411V7iR/)
+ [Geochemistry π - Potential Issues with pip Installation in China - Keran Li (Kirk)](https://www.bilibili.com/video/BV1Gs4y1d7Cm/)
+ [Geochemistry π - Solutions for Failed pip Installation in China - Keran Li (Kirk)](https://www.bilibili.com/video/BV1zg4y1j7bx/)
+ [Geochemistry π - Command-Line Version Operation Demonstration Video](https://www.bilibili.com/video/BV1Tv4y1C79k/)
+ [Download and Run the Beta Version](https://www.bilibili.com/video/BV1UM4y1Q7Ju/)

### 4. Installing and Model Running Docs
+ [Installation](https://geochemistrypi.readthedocs.io/en/latest/Installation.html)
+ [Data-preprocessing](https:/geochemistrypi.readthedocs.io/en/latest/Model%20Example/Data_Preprocessing/Data%20Preprocessing.html)
+ [Clustering](https://geochemistrypi.readthedocs.io/en/latest/Model%20Example/Clustering/Clustering.html)
+ [Classification](https://geochemistrypi.readthedocs.io/en/latest/Model%20Example/Classification/classification.html)
+ [Decomposition](https://geochemistrypi.readthedocs.io/en/latest/Model%20Example/Decomposition/decomposition.html)
+ [Regression](https://geochemistrypi.readthedocs.io/en/latest/Model%20Example/Regression/Regression.html)

### 5. Users Feedback Doc
+ [User's feedback](https://docs.qq.com/doc/DTmp0eWxQUFpSdlFp?u=0451ba1d1a654ecfa28a8bd61c561c22)
